==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/inputs/DataLakeStorageAccountDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.inputs

import com.pulumi.azurenative.synapse.inputs.DataLakeStorageAccountDetailsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Details of the data lake storage account associated with the workspace
 * @property accountUrl Account URL
 * @property createManagedPrivateEndpoint Create managed private endpoint to this storage account or not
 * @property filesystem Filesystem name
 * @property resourceId ARM resource Id of this storage account
 */
public data class DataLakeStorageAccountDetailsArgs(
    public val accountUrl: Output<String>? = null,
    public val createManagedPrivateEndpoint: Output<Boolean>? = null,
    public val filesystem: Output<String>? = null,
    public val resourceId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.synapse.inputs.DataLakeStorageAccountDetailsArgs> {
    override fun toJava(): com.pulumi.azurenative.synapse.inputs.DataLakeStorageAccountDetailsArgs =
        com.pulumi.azurenative.synapse.inputs.DataLakeStorageAccountDetailsArgs.builder()
            .accountUrl(accountUrl?.applyValue({ args0 -> args0 }))
            .createManagedPrivateEndpoint(createManagedPrivateEndpoint?.applyValue({ args0 -> args0 }))
            .filesystem(filesystem?.applyValue({ args0 -> args0 }))
            .resourceId(resourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DataLakeStorageAccountDetailsArgs].
 */
@PulumiTagMarker
public class DataLakeStorageAccountDetailsArgsBuilder internal constructor() {
    private var accountUrl: Output<String>? = null

    private var createManagedPrivateEndpoint: Output<Boolean>? = null

    private var filesystem: Output<String>? = null

    private var resourceId: Output<String>? = null

    /**
     * @param value Account URL
     */
    @JvmName("xjajsxumhgvwtggi")
    public suspend fun accountUrl(`value`: Output<String>) {
        this.accountUrl = value
    }

    /**
     * @param value Create managed private endpoint to this storage account or not
     */
    @JvmName("qwxsuqsfxfdeehhb")
    public suspend fun createManagedPrivateEndpoint(`value`: Output<Boolean>) {
        this.createManagedPrivateEndpoint = value
    }

    /**
     * @param value Filesystem name
     */
    @JvmName("swtclvqooullcutb")
    public suspend fun filesystem(`value`: Output<String>) {
        this.filesystem = value
    }

    /**
     * @param value ARM resource Id of this storage account
     */
    @JvmName("ayqalatufrrhglqt")
    public suspend fun resourceId(`value`: Output<String>) {
        this.resourceId = value
    }

    /**
     * @param value Account URL
     */
    @JvmName("rrudbhjxiqxvwtqo")
    public suspend fun accountUrl(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.accountUrl = mapped
    }

    /**
     * @param value Create managed private endpoint to this storage account or not
     */
    @JvmName("vlrscpksuijfyonj")
    public suspend fun createManagedPrivateEndpoint(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.createManagedPrivateEndpoint = mapped
    }

    /**
     * @param value Filesystem name
     */
    @JvmName("mknibbfkqwcpwfrv")
    public suspend fun filesystem(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.filesystem = mapped
    }

    /**
     * @param value ARM resource Id of this storage account
     */
    @JvmName("ukyryedjejkvkorp")
    public suspend fun resourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceId = mapped
    }

    internal fun build(): DataLakeStorageAccountDetailsArgs = DataLakeStorageAccountDetailsArgs(
        accountUrl = accountUrl,
        createManagedPrivateEndpoint = createManagedPrivateEndpoint,
        filesystem = filesystem,
        resourceId = resourceId,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/inputs/DataLakeStorageAccountDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.inputs

import com.pulumi.azurenative.synapse.inputs.DataLakeStorageAccountDetailsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Details of the data lake storage account associated with the workspace
 * @property accountUrl Account URL
 * @property createManagedPrivateEndpoint Create managed private endpoint to this storage account or not
 * @property filesystem Filesystem name
 * @property resourceId ARM resource Id of this storage account
 */
public data class DataLakeStorageAccountDetailsArgs(
    public val accountUrl: Output<String>? = null,
    public val createManagedPrivateEndpoint: Output<Boolean>? = null,
    public val filesystem: Output<String>? = null,
    public val resourceId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.synapse.inputs.DataLakeStorageAccountDetailsArgs> {
    override fun toJava(): com.pulumi.azurenative.synapse.inputs.DataLakeStorageAccountDetailsArgs =
        com.pulumi.azurenative.synapse.inputs.DataLakeStorageAccountDetailsArgs.builder()
            .accountUrl(accountUrl?.applyValue({ args0 -> args0 }))
            .createManagedPrivateEndpoint(createManagedPrivateEndpoint?.applyValue({ args0 -> args0 }))
            .filesystem(filesystem?.applyValue({ args0 -> args0 }))
            .resourceId(resourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DataLakeStorageAccountDetailsArgs].
 */
@PulumiTagMarker
public class DataLakeStorageAccountDetailsArgsBuilder internal constructor() {
    private var accountUrl: Output<String>? = null

    private var createManagedPrivateEndpoint: Output<Boolean>? = null

    private var filesystem: Output<String>? = null

    private var resourceId: Output<String>? = null

    /**
     * @param value Account URL
     */
    @JvmName("fbiyljriafdufhrw")
    public suspend fun accountUrl(`value`: Output<String>) {
        this.accountUrl = value
    }

    /**
     * @param value Create managed private endpoint to this storage account or not
     */
    @JvmName("qujrvkghqdkvgxrp")
    public suspend fun createManagedPrivateEndpoint(`value`: Output<Boolean>) {
        this.createManagedPrivateEndpoint = value
    }

    /**
     * @param value Filesystem name
     */
    @JvmName("alntcmnhwsftnivg")
    public suspend fun filesystem(`value`: Output<String>) {
        this.filesystem = value
    }

    /**
     * @param value ARM resource Id of this storage account
     */
    @JvmName("jvlmmfikgfbhijsx")
    public suspend fun resourceId(`value`: Output<String>) {
        this.resourceId = value
    }

    /**
     * @param value Account URL
     */
    @JvmName("jensbxkbrtjoolqg")
    public suspend fun accountUrl(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.accountUrl = mapped
    }

    /**
     * @param value Create managed private endpoint to this storage account or not
     */
    @JvmName("dqmiwlloociniswk")
    public suspend fun createManagedPrivateEndpoint(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.createManagedPrivateEndpoint = mapped
    }

    /**
     * @param value Filesystem name
     */
    @JvmName("gbxwoyjsrupdbvwv")
    public suspend fun filesystem(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.filesystem = mapped
    }

    /**
     * @param value ARM resource Id of this storage account
     */
    @JvmName("vigmndhmileciwfi")
    public suspend fun resourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceId = mapped
    }

    internal fun build(): DataLakeStorageAccountDetailsArgs = DataLakeStorageAccountDetailsArgs(
        accountUrl = accountUrl,
        createManagedPrivateEndpoint = createManagedPrivateEndpoint,
        filesystem = filesystem,
        resourceId = resourceId,
    )
}
